/* Generated by Font Squirrel (http://www.fontsquirrel.com) on February 2, 2016 */



@font-face {
    font-family: 'karmillabold';
    src: url('karmilla-bold-015-webfont.eot');
    src: url('karmilla-bold-015-webfont.eot?#iefix') format('embedded-opentype'),
         url('karmilla-bold-015-webfont.woff2') format('woff2'),
         url('karmilla-bold-015-webfont.woff') format('woff'),
         url('karmilla-bold-015-webfont.ttf') format('truetype'),
         url('karmilla-bold-015-webfont.svg#karmillabold') format('svg');
    font-weight: normal;
    font-style: normal;

}




@font-face {
    font-family: 'karmillaregular';
    src: url('karmilla-regular-015-webfont.eot');
    src: url('karmilla-regular-015-webfont.eot?#iefix') format('embedded-opentype'),
         url('karmilla-regular-015-webfont.woff2') format('woff2'),
         url('karmilla-regular-015-webfont.woff') format('woff'),
         url('karmilla-regular-015-webfont.ttf') format('truetype'),
         url('karmilla-regular-015-webfont.svg#karmillaregular') format('svg');
    font-weight: normal;
    font-style: normal;

}